Exception: NotValidName

Inherits:
StandardError
  • Object
show all
Defined in:
lib/main.rb

Overview

Error handling classes for input validation

Instance Method Summary collapse

Constructor Details

#initialize(msg = "\nForgetful doge, surely you remember your own name? (Name can only contain letters and must be less than 8 characters)".light_blue) ⇒ NotValidName



10
11
12
# File 'lib/main.rb', line 10

def initialize(msg="\nForgetful doge, surely you remember your own name? (Name can only contain letters and must be less than 8 characters)".light_blue)
super(msg)
end