Exception: NotValidName
- Inherits:
-
StandardError
- Object
- StandardError
- NotValidName
- Defined in:
- lib/main.rb
Overview
Error handling classes for input validation
Instance Method Summary collapse
-
#initialize(msg = "\nForgetful doge, surely you remember your own name? (Name can only contain letters and must be less than 8 characters)".light_blue) ⇒ NotValidName
constructor
A new instance of NotValidName.
Constructor Details
#initialize(msg = "\nForgetful doge, surely you remember your own name? (Name can only contain letters and must be less than 8 characters)".light_blue) ⇒ NotValidName
Returns a new instance of NotValidName.
10 11 12 |
# File 'lib/main.rb', line 10 def initialize(msg="\nForgetful doge, surely you remember your own name? (Name can only contain letters and must be less than 8 characters)".light_blue) super(msg) end |